==> h2o-java-rest-bindings-3.8.2.2-sources.jar: water/bindings/pojos/NodeV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;
public class NodeV3 extends Schema {
    /** IP */
    public String h2o;

    /** IP address and port in the form a.b.c.d:e */
    public String ip_port;

    /** (now-last_ping)<HeartbeatThread.TIMEOUT */
    public boolean healthy;

    /** Time (in msec) of last ping */
    public long last_ping;

    /** PID */
    public int pid;

    /** num_cpus */
    public int num_cpus;

    /** cpus_allowed */
    public int cpus_allowed;

    /** nthreads */
    public int nthreads;

    /** System load; average #runnables/#cores */
    public float sys_load;

    /** System CPU percentage used by this H2O process in last interval */
    public int my_cpu_pct;

    /** System CPU percentage used by everything in last interval */
    public int sys_cpu_pct;

    /** Data on Node memory */
    public long mem_value_size;

    /** Temp (non Data) memory */
    public long pojo_mem;

    /** Free heap */
    public long free_mem;

    /** Maximum memory size for node */
    public long max_mem;

    /** Size of data on node's disk */
    public long swap_mem;

    /** #local keys */
    public int num_keys;

    /** Free disk */
    public long free_disk;

    /** Max disk */
    public long max_disk;

    /** Active Remote Procedure Calls */
    public int rpcs_active;

    /** F/J Thread count, by priority */
    public short[] fjthrds;

    /** F/J Task count, by priority */
    public short[] fjqueue;

    /** Open TCP connections */
    public int tcps_active;

    /** Open File Descripters */
    public int open_fds;

    /** Linpack GFlops */
    public double gflops;

    /** Memory Bandwidth */
    public double mem_bw;

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}

==> h2o-java-rest-bindings-3.8.2.4-sources.jar: water/bindings/pojos/NodeV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;

public class NodeV3 extends Schema {
    /** IP */
    public String h2o;

    /** IP address and port in the form a.b.c.d:e */
    public String ip_port;

    /** (now-last_ping)<HeartbeatThread.TIMEOUT */
    public boolean healthy;

    /** Time (in msec) of last ping */
    public long last_ping;

    /** PID */
    public int pid;

    /** num_cpus */
    public int num_cpus;

    /** cpus_allowed */
    public int cpus_allowed;

    /** nthreads */
    public int nthreads;

    /** System load; average #runnables/#cores */
    public float sys_load;

    /** System CPU percentage used by this H2O process in last interval */
    public int my_cpu_pct;

    /** System CPU percentage used by everything in last interval */
    public int sys_cpu_pct;

    /** Data on Node memory */
    public long mem_value_size;

    /** Temp (non Data) memory */
    public long pojo_mem;

    /** Free heap */
    public long free_mem;

    /** Maximum memory size for node */
    public long max_mem;

    /** Size of data on node's disk */
    public long swap_mem;

    /** #local keys */
    public int num_keys;

    /** Free disk */
    public long free_disk;

    /** Max disk */
    public long max_disk;

    /** Active Remote Procedure Calls */
    public int rpcs_active;

    /** F/J Thread count, by priority */
    public short[] fjthrds;

    /** F/J Task count, by priority */
    public short[] fjqueue;

    /** Open TCP connections */
    public int tcps_active;

    /** Open File Descripters */
    public int open_fds;

    /** Linpack GFlops */
    public double gflops;

    /** Memory Bandwidth */
    public double mem_bw;

    public NodeV3() {
        h2o = "";
        ip_port = "";
        healthy = false;
        last_ping = 0L;
        pid = 0;
        num_cpus = 0;
        cpus_allowed = 0;
        nthreads = 0;
        sys_load = 0.0f;
        my_cpu_pct = 0;
        sys_cpu_pct = 0;
        mem_value_size = 0L;
        pojo_mem = 0L;
        free_mem = 0L;
        max_mem = 0L;
        swap_mem = 0L;
        num_keys = 0;
        free_disk = 0L;
        max_disk = 0L;
        rpcs_active = 0;
        fjthrds = null;
        fjqueue = null;
        tcps_active = 0;
        open_fds = 0;
        gflops = 0.0;
        mem_bw = 0.0;
    }

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}
